[![Build Status](https://github.com/hukkinj1/mdformat-config/workflows/Tests/badge.svg?branch=master)](<https://github.com/hukkinj1/mdformat-config/actions?query=workflow%3ATests+branch%3Amaster+event%3Apush>)
[![PyPI version](https://badge.fury.io/py/mdformat-config.svg)](<https://badge.fury.io/py/mdformat-config>)

# mdformat-config
> Mdformat plugin to beautify configuration and data-serialization formats

## Description
mdformat-config is an [mdformat](https://github.com/executablebooks/mdformat) plugin
that makes mdformat beautify configuration and data-serialization formats.
Currently supported formats are JSON, TOML and YAML.

## Usage
Install with:
```console
pip install mdformat-config
```
